function [ y1b, y1a ] = coupled_AR( LEN )
%Generates coupled AR processes
% Inputs - 
%   Take the length of the series as input LEN
%Outputs-
%   y1b - dependent AR(1) process
%   y1a - independent AR(1) process 
%
%
%
% Aditi Kathpalia, Nithin Nagaraj, NIAS, October 2017

%Parameters for addition of noise/asynchronous measurements
%
punc_flag=0;        %Set to one to introduce asynchronicity in measurements - introduces missing data at random points in y1b
punc_percent=10;    %Set the percentage of asynchronous measurements (percentage of missing data in y1b at random locations)
neu=0.03;           %Intensity of noise - change the value to change the level of noise in y1a and y1b

%coefficients of the process
phi_0 = 0;          %mean of the process is zero 
phi_1_a = 0.8;
phi_1_b =0.9;
phi_1_cause_b = 0.8;

%Generate additive noise
gamma = randn(LEN,1); 
gamma2 = randn(LEN,1);

y1a=zeros(LEN,1);
y1a(1)=rand(1,1);
I=2;
while I<=LEN;
   y1a(I)=y1a(I-1)*phi_1_a+neu*gamma(I);
   I=I+1;
end;

y1b=zeros(LEN,1);
y1b(1)=rand(1,1);
I=2;
while I<=LEN;
            y1b(I)=y1b(I-1)*phi_1_b+y1a(I-1)*phi_1_cause_b+neu*gamma2(I);
            I=I+1;
end;

if punc_flag==1
PUNC = (punc_percent/100)*LEN;
[ y1b,PUNC_locs2 ] = puncture( y1b, PUNC, []);
y1b = y1b';
end
